@@ -1,6 +1,7 @@
 # system configuration generated and used by the sysconfig module
 build_time_vars = {'ABIFLAGS': '',
  'AC_APPLE_UNIVERSAL_BUILD': 0,
+ 'AIX_BUILDDATE': 0,
  'AIX_GENUINE_CPLUSPLUS': 0,
  'ALT_SOABI': 0,
  'ANDROID_API_LEVEL': 0,
@@ -9,75 +10,84 @@ build_time_vars = {'ABIFLAGS': '',
  'BASECFLAGS': '-Wno-unused-result -Wsign-compare',
  'BASECPPFLAGS': '',
  'BASEMODLIBS': '',
- 'BINDIR': '/usr/pkg/bin',
- 'BINLIBDEST': '/usr/pkg/lib/python3.8',
- 'BLDLIBRARY': '-L. -lpython3.8',
- 'BLDSHARED': 'cc -shared -L. -Wl,-zrelro -L/usr/lib64 -Wl,-R/usr/lib64 '
-              '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib -Wl,-zrelro -L/usr/lib64 '
-              '-Wl,-R/usr/lib64 -L/usr/pkg/lib -Wl,-R/usr/pkg/lib',
+ 'BINDIR': '/2022Q1/bin',
+ 'BINLIBDEST': '/2022Q1/lib/python3.9',
+ 'BLDLIBRARY': '-L. -lpython3.9',
+ 'BLDSHARED': 'cc -pthread -shared -L. '
+              '-L/2022Q1/gcc7/lib/gcc/x86_64-unknown-linux/7.5.0 '
+              '-Wl,-R/2022Q1/gcc7/lib/gcc/x86_64-unknown-linux/7.5.0 '
+              '-L/2022Q1/gcc7/lib64 -Wl,-R/2022Q1/gcc7/lib64 -Wl,-zrelro '
+              '-L/2022Q1/lib -Wl,-R/2022Q1/lib '
+              '-L/2022Q1/gcc7/lib/gcc/x86_64-unknown-linux/7.5.0 '
+              '-Wl,-R/2022Q1/gcc7/lib/gcc/x86_64-unknown-linux/7.5.0 '
+              '-L/2022Q1/gcc7/lib64 -Wl,-R/2022Q1/gcc7/lib64 -Wl,-zrelro '
+              '-L/2022Q1/lib -Wl,-R/2022Q1/lib',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
  'BUILD_GNU_TYPE': 'x86_64-unknown-linux-gnu',
  'BYTESTR_DEPS': '\\',
- 'CC': 'cc',
+ 'CC': 'cc -pthread',
  'CCSHARED': '-fPIC',
  'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 -D_FORTIFY_SOURCE=2 '
-           '-I/usr/include -I/usr/pkg/include -I/usr/pkg/include/ncurses '
-           '-I/usr/pkg/include/db4 -O2 -D_FORTIFY_SOURCE=2 -I/usr/include '
-           '-I/usr/pkg/include -I/usr/pkg/include/ncurses '
-           '-I/usr/pkg/include/db4 -O2 -D_FORTIFY_SOURCE=2 -I/usr/include '
-           '-I/usr/pkg/include -I/usr/pkg/include/ncurses '
-           '-I/usr/pkg/include/db4',
+           '-I/usr/include -I/2022Q1/include -I/2022Q1/include/ncurses '
+           '-I/2022Q1/include/db4 -O2 -D_FORTIFY_SOURCE=2 -I/usr/include '
+           '-I/2022Q1/include -I/2022Q1/include/ncurses -I/2022Q1/include/db4 '
+           '-O2 -D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q1/include '
+           '-I/2022Q1/include/ncurses -I/2022Q1/include/db4',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
- 'CONFIGURE_CFLAGS': '-O2 -D_FORTIFY_SOURCE=2 -I/usr/include '
-                     '-I/usr/pkg/include -I/usr/pkg/include/ncurses '
-                     '-I/usr/pkg/include/db4',
+ 'CONFIGURE_CFLAGS': '-O2 -D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q1/include '
+                     '-I/2022Q1/include/ncurses -I/2022Q1/include/db4',
  'CONFIGURE_CFLAGS_NODIST': '-std=gnu99 -Wextra -Wno-unused-result '
                             '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
-                            '-Werror=implicit-function-declaration',
- 'CONFIGURE_CPPFLAGS': '-I/usr/include -I/usr/pkg/include '
-                       '-I/usr/pkg/include/ncurses -I/usr/pkg/include/db4',
- 'CONFIGURE_LDFLAGS': '-Wl,-zrelro -L/usr/lib64 -Wl,-R/usr/lib64 '
-                      '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib',
+                            '-Werror=implicit-function-declaration '
+                            '-fvisibility=hidden',
+ 'CONFIGURE_CPPFLAGS': '-I/usr/include -I/2022Q1/include '
+                       '-I/2022Q1/include/ncurses -I/2022Q1/include/db4',
+ 'CONFIGURE_LDFLAGS': '-L/2022Q1/gcc7/lib/gcc/x86_64-unknown-linux/7.5.0 '
+                      '-Wl,-R/2022Q1/gcc7/lib/gcc/x86_64-unknown-linux/7.5.0 '
+                      '-L/2022Q1/gcc7/lib64 -Wl,-R/2022Q1/gcc7/lib64 '
+                      '-Wl,-zrelro -L/2022Q1/lib -Wl,-R/2022Q1/lib',
  'CONFIGURE_LDFLAGS_NODIST': '',
- 'CONFIG_ARGS': "'--enable-shared' '--with-openssl=/usr/pkg' "
+ 'CONFIG_ARGS': "'--enable-shared' '--with-openssl=/2022Q1' "
                 "'--with-system-ffi' '--without-ensurepip' "
-                "'--without-pymalloc' '--prefix=/usr/pkg' "
+                "'--without-pymalloc' '--prefix=/2022Q1' "
                 "'--build=x86_64-unknown-linux' '--host=x86_64-unknown-linux' "
-                "'--mandir=/usr/pkg/man' '--enable-option-checking=yes' "
+                "'--mandir=/2022Q1/man' '--enable-option-checking=yes' "
                 "'build_alias=x86_64-unknown-linux' "
                 "'host_alias=x86_64-unknown-linux' 'CC=cc' 'CFLAGS=-O2 "
-                '-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include '
-                "-I/usr/pkg/include/ncurses -I/usr/pkg/include/db4' "
-                "'LDFLAGS=-Wl,-zrelro -L/usr/lib64 -Wl,-R/usr/lib64 "
-                "-L/usr/pkg/lib -Wl,-R/usr/pkg/lib' 'LIBS=' "
-                "'CPPFLAGS=-I/usr/include -I/usr/pkg/include "
-                "-I/usr/pkg/include/ncurses -I/usr/pkg/include/db4' "
-                "'PKG_CONFIG=/usr/pkgsrc/lang/python38/work/.tools/bin/pkg-config' "
+                '-D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q1/include '
+                "-I/2022Q1/include/ncurses -I/2022Q1/include/db4' "
+                "'LDFLAGS=-L/2022Q1/gcc7/lib/gcc/x86_64-unknown-linux/7.5.0 "
+                '-Wl,-R/2022Q1/gcc7/lib/gcc/x86_64-unknown-linux/7.5.0 '
+                '-L/2022Q1/gcc7/lib64 -Wl,-R/2022Q1/gcc7/lib64 -Wl,-zrelro '
+                "-L/2022Q1/lib -Wl,-R/2022Q1/lib' 'LIBS=' "
+                "'CPPFLAGS=-I/usr/include -I/2022Q1/include "
+                "-I/2022Q1/include/ncurses -I/2022Q1/include/db4' "
+                "'PKG_CONFIG=/root/sda3/pkgsrc.2022Q1/lang/python39/work/.tools/bin/pkg-config' "
                 "'PKG_CONFIG_PATH=' "
-                "'PKG_CONFIG_LIBDIR=/usr/pkgsrc/lang/python38/work/.buildlink/lib64/pkgconfig:/usr/pkgsrc/lang/python38/work/.buildlink/lib/pkgconfig:/usr/pkgsrc/lang/python38/work/.buildlink/share/pkgconfig'",
- 'CONFINCLUDEDIR': '/usr/pkg/include',
- 'CONFINCLUDEPY': '/usr/pkg/include/python3.8',
+                "'PKG_CONFIG_LIBDIR=/root/sda3/pkgsrc.2022Q1/lang/python39/work/.buildlink/lib64/pkgconfig:/root/sda3/pkgsrc.2022Q1/lang/python39/work/.buildlink/lib/pkgconfig:/root/sda3/pkgsrc.2022Q1/lang/python39/work/.buildlink/share/pkgconfig'",
+ 'CONFINCLUDEDIR': '/2022Q1/include',
+ 'CONFINCLUDEPY': '/2022Q1/include/python3.9',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/usr/pkgsrc/lang/python38/work/Python-3.8.14/coverage.info',
- 'COVERAGE_REPORT': '/usr/pkgsrc/lang/python38/work/Python-3.8.14/lcov-report',
+ 'COVERAGE_INFO': '/root/sda3/pkgsrc.2022Q1/lang/python39/work/Python-3.9.12/coverage.info',
+ 'COVERAGE_REPORT': '/root/sda3/pkgsrc.2022Q1/lang/python39/work/Python-3.9.12/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
- 'CPPFLAGS': '-I. -I./Include -I/usr/include -I/usr/pkg/include '
-             '-I/usr/pkg/include/ncurses -I/usr/pkg/include/db4 -I/usr/include '
-             '-I/usr/pkg/include -I/usr/pkg/include/ncurses '
-             '-I/usr/pkg/include/db4',
- 'CXX': 'c++',
- 'DESTDIRS': '/usr/pkg /usr/pkg/lib /usr/pkg/lib/python3.8 '
-             '/usr/pkg/lib/python3.8/lib-dynload',
- 'DESTLIB': '/usr/pkg/lib/python3.8',
+ 'CPPFLAGS': '-I. -I./Include -I/usr/include -I/2022Q1/include '
+             '-I/2022Q1/include/ncurses -I/2022Q1/include/db4 -I/usr/include '
+             '-I/2022Q1/include -I/2022Q1/include/ncurses '
+             '-I/2022Q1/include/db4',
+ 'CXX': 'c++ -pthread',
+ 'DESTDIRS': '/2022Q1 /2022Q1/lib /2022Q1/lib/python3.9 '
+             '/2022Q1/lib/python3.9/lib-dynload',
+ 'DESTLIB': '/2022Q1/lib/python3.9',
  'DESTPATH': '',
- 'DESTSHARED': '/usr/pkg/lib/python3.8/lib-dynload',
+ 'DESTSHARED': '/2022Q1/lib/python3.9/lib-dynload',
  'DFLAGS': '',
  'DIRMODE': 755,
  'DIST': 'README.rst ChangeLog configure configure.ac acconfig.h pyconfig.h.in '
@@ -99,6 +109,8 @@ build_time_vars = {'ABIFLAGS': '',
  'ENSUREPIP': 'no',
  'EXE': '',
  'EXEMODE': 755,
+ 'EXPORTSFROM': '',
+ 'EXPORTSYMS': '',
  'EXTRATESTOPTS': '',
  'EXTRA_CFLAGS': '',
  'EXT_SUFFIX': '.so',
@@ -106,7 +118,6 @@ build_time_vars = {'ABIFLAGS': '',
  'FLOAT_WORDS_BIGENDIAN': 0,
  'FLOCK_NEEDS_LIBBSD': 0,
  'GETPGRP_HAVE_ARG': 0,
- 'GETTIMEOFDAY_NO_TZ': 0,
  'GITBRANCH': '',
  'GITTAG': '',
  'GITVERSION': '',
@@ -262,7 +273,6 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_GETSID': 1,
  'HAVE_GETSPENT': 1,
  'HAVE_GETSPNAM': 1,
- 'HAVE_GETTIMEOFDAY': 1,
  'HAVE_GETWD': 1,
  'HAVE_GLIBC_MEMMOVE_BUG': 0,
  'HAVE_GRP_H': 1,
@@ -294,18 +304,23 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_LIBRESOLV': 0,
  'HAVE_LIBSENDFILE': 0,
  'HAVE_LIBUTIL_H': 0,
+ 'HAVE_LIBUUID': 1,
  'HAVE_LINK': 1,
  'HAVE_LINKAT': 1,
+ 'HAVE_LINUX_AUXVEC_H': 1,
  'HAVE_LINUX_CAN_BCM_H': 1,
  'HAVE_LINUX_CAN_H': 1,
+ 'HAVE_LINUX_CAN_J1939_H': 1,
  'HAVE_LINUX_CAN_RAW_FD_FRAMES': 1,
  'HAVE_LINUX_CAN_RAW_H': 1,
+ 'HAVE_LINUX_CAN_RAW_JOIN_FILTERS': 1,
  'HAVE_LINUX_MEMFD_H': 1,
  'HAVE_LINUX_NETLINK_H': 1,
  'HAVE_LINUX_QRTR_H': 1,
  'HAVE_LINUX_RANDOM_H': 1,
  'HAVE_LINUX_TIPC_H': 1,
  'HAVE_LINUX_VM_SOCKETS_H': 1,
+ 'HAVE_LINUX_WAIT_H': 1,
  'HAVE_LOCKF': 1,
  'HAVE_LOG1P': 1,
  'HAVE_LOG2': 1,
@@ -332,6 +347,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_NETPACKET_PACKET_H': 1,
  'HAVE_NET_IF_H': 1,
  'HAVE_NICE': 1,
+ 'HAVE_NON_UNICODE_WCHAR_T_REPRESENTATION': 0,
  'HAVE_OPENAT': 1,
  'HAVE_OPENPTY': 1,
  'HAVE_PATHCONF': 1,
@@ -358,7 +374,6 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_PTHREAD_KILL': 1,
  'HAVE_PTHREAD_SIGMASK': 1,
  'HAVE_PTY_H': 1,
- 'HAVE_PUTENV': 1,
  'HAVE_PWRITE': 1,
  'HAVE_PWRITEV': 1,
  'HAVE_PWRITEV2': 1,
@@ -383,6 +398,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SCHED_SETAFFINITY': 1,
  'HAVE_SCHED_SETPARAM': 1,
  'HAVE_SCHED_SETSCHEDULER': 1,
+ 'HAVE_SEM_CLOCKWAIT': 1,
  'HAVE_SEM_GETVALUE': 1,
  'HAVE_SEM_OPEN': 1,
  'HAVE_SEM_TIMEDWAIT': 1,
@@ -455,6 +471,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SYSCONF': 1,
  'HAVE_SYSEXITS_H': 1,
  'HAVE_SYS_AUDIOIO_H': 0,
+ 'HAVE_SYS_AUXV_H': 1,
  'HAVE_SYS_BSDTTY_H': 0,
  'HAVE_SYS_DEVPOLL_H': 0,
  'HAVE_SYS_DIR_H': 0,
@@ -510,7 +527,6 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_UNAME': 1,
  'HAVE_UNISTD_H': 1,
  'HAVE_UNLINKAT': 1,
- 'HAVE_UNSETENV': 1,
  'HAVE_USABLE_WCHAR_T': 0,
  'HAVE_UTIL_H': 0,
  'HAVE_UTIMENSAT': 1,
@@ -536,45 +552,56 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
  'HOST_GNU_TYPE': 'x86_64-unknown-linux-gnu',
- 'INCLDIRSTOMAKE': '/usr/pkg/include /usr/pkg/include '
-                   '/usr/pkg/include/python3.8 /usr/pkg/include/python3.8',
- 'INCLUDEDIR': '/usr/pkg/include',
- 'INCLUDEPY': '/usr/pkg/include/python3.8',
- 'INSTALL': '/usr/bin/install -c -o root -g root',
- 'INSTALL_DATA': '/usr/bin/install -c -o root -g root -m 644',
- 'INSTALL_PROGRAM': '/usr/bin/install -c -s -o root -g root -m 755',
- 'INSTALL_SCRIPT': '/usr/bin/install -c -o root -g root -m 755',
- 'INSTALL_SHARED': '/usr/bin/install -c -o root -g root -m 755',
- 'INSTSONAME': 'libpython3.8.so.1.0',
+ 'INCLDIRSTOMAKE': '/2022Q1/include /2022Q1/include /2022Q1/include/python3.9 '
+                   '/2022Q1/include/python3.9',
+ 'INCLUDEDIR': '/2022Q1/include',
+ 'INCLUDEPY': '/2022Q1/include/python3.9',
+ 'INSTALL': '/bin/install -c -o root -g root',
+ 'INSTALL_DATA': '/bin/install -c -o root -g root -m 644',
+ 'INSTALL_PROGRAM': '/bin/install -c -s -o root -g root -m 755',
+ 'INSTALL_SCRIPT': '/bin/install -c -o root -g root -m 755',
+ 'INSTALL_SHARED': '/bin/install -c -o root -g root -m 755',
+ 'INSTSONAME': 'libpython3.9.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
- 'LDCXXSHARED': 'c++ -shared',
- 'LDFLAGS': '-L. -Wl,-zrelro -L/usr/lib64 -Wl,-R/usr/lib64 -L/usr/pkg/lib '
-            '-Wl,-R/usr/pkg/lib -Wl,-zrelro -L/usr/lib64 -Wl,-R/usr/lib64 '
-            '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib',
+ 'LDCXXSHARED': 'c++ -pthread -shared',
+ 'LDFLAGS': '-L. -L/2022Q1/gcc7/lib/gcc/x86_64-unknown-linux/7.5.0 '
+            '-Wl,-R/2022Q1/gcc7/lib/gcc/x86_64-unknown-linux/7.5.0 '
+            '-L/2022Q1/gcc7/lib64 -Wl,-R/2022Q1/gcc7/lib64 -Wl,-zrelro '
+            '-L/2022Q1/lib -Wl,-R/2022Q1/lib '
+            '-L/2022Q1/gcc7/lib/gcc/x86_64-unknown-linux/7.5.0 '
+            '-Wl,-R/2022Q1/gcc7/lib/gcc/x86_64-unknown-linux/7.5.0 '
+            '-L/2022Q1/gcc7/lib64 -Wl,-R/2022Q1/gcc7/lib64 -Wl,-zrelro '
+            '-L/2022Q1/lib -Wl,-R/2022Q1/lib',
  'LDFLAGS_NODIST': '',
- 'LDLIBRARY': 'libpython3.8.so',
+ 'LDLIBRARY': 'libpython3.9.so',
  'LDLIBRARYDIR': '',
- 'LDSHARED': 'cc -shared -L. -Wl,-zrelro -L/usr/lib64 -Wl,-R/usr/lib64 '
-             '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib -Wl,-zrelro -L/usr/lib64 '
-             '-Wl,-R/usr/lib64 -L/usr/pkg/lib -Wl,-R/usr/pkg/lib',
- 'LDVERSION': '3.8',
+ 'LDSHARED': 'cc -pthread -shared -L. '
+             '-L/2022Q1/gcc7/lib/gcc/x86_64-unknown-linux/7.5.0 '
+             '-Wl,-R/2022Q1/gcc7/lib/gcc/x86_64-unknown-linux/7.5.0 '
+             '-L/2022Q1/gcc7/lib64 -Wl,-R/2022Q1/gcc7/lib64 -Wl,-zrelro '
+             '-L/2022Q1/lib -Wl,-R/2022Q1/lib '
+             '-L/2022Q1/gcc7/lib/gcc/x86_64-unknown-linux/7.5.0 '
+             '-Wl,-R/2022Q1/gcc7/lib/gcc/x86_64-unknown-linux/7.5.0 '
+             '-L/2022Q1/gcc7/lib64 -Wl,-R/2022Q1/gcc7/lib64 -Wl,-zrelro '
+             '-L/2022Q1/lib -Wl,-R/2022Q1/lib',
+ 'LDVERSION': '3.9',
  'LIBC': '',
- 'LIBDEST': '/usr/pkg/lib/python3.8',
- 'LIBDIR': '/usr/pkg/lib',
- 'LIBFFI_INCLUDEDIR': '/usr/pkg/include',
+ 'LIBDEST': '/2022Q1/lib/python3.9',
+ 'LIBDIR': '/2022Q1/lib',
+ 'LIBFFI_INCLUDEDIR': '/2022Q1/include',
  'LIBM': '-lm',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
- 'LIBPC': '/usr/pkg/lib/pkgconfig',
- 'LIBPL': '/usr/pkg/lib/python3.8/config-3.8',
+ 'LIBPC': '/2022Q1/lib/pkgconfig',
+ 'LIBPL': '/2022Q1/lib/python3.9/config-3.9',
  'LIBPYTHON': '',
- 'LIBRARY': 'libpython3.8.a',
+ 'LIBRARY': 'libpython3.9.a',
  'LIBRARY_OBJS': '\\',
  'LIBRARY_OBJS_OMIT_FROZEN': '\\',
- 'LIBS': '-lcrypt -lintl -ldl  -lm',
+ 'LIBS': '-lcrypt -lintl -lpthread -ldl  -lutil -lm',
  'LIBSUBDIRS': 'tkinter tkinter/test tkinter/test/test_tkinter \\',
- 'LINKCC': 'cc',
+ 'LINKCC': 'cc -pthread',
  'LINKFORSHARED': '-Xlinker -export-dynamic',
  'LIPO_32BIT_FLAGS': '',
  'LIPO_INTEL64_FLAGS': '',
@@ -585,18 +612,18 @@ build_time_vars = {'ABIFLAGS': '',
  'LOCALMODLIBS': '',
  'MACHDEP': 'linux',
  'MACHDEP_OBJS': '',
- 'MACHDESTLIB': '/usr/pkg/lib/python3.8',
+ 'MACHDESTLIB': '/2022Q1/lib/python3.9',
  'MACOSX_DEPLOYMENT_TARGET': '',
- 'MAINCC': 'cc',
+ 'MAINCC': 'cc -pthread',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 1,
  'MAKESETUP': './Modules/makesetup',
- 'MANDIR': '/usr/pkg/man',
+ 'MANDIR': '/2022Q1/man',
  'MKDIR_P': '/bin/mkdir -p',
  'MODBUILT_NAMES': 'posix  errno  pwd  _sre  _codecs  _weakref  _functools  '
                    '_operator  _collections  _abc  itertools  atexit  _signal  '
                    '_stat  time  _thread  _locale  _io  faulthandler  '
-                   '_tracemalloc  _symtable  xxsubtype',
+                   '_tracemalloc  _peg_parser  _symtable  xxsubtype',
  'MODDISABLED_NAMES': '',
  'MODLIBS': '',
  'MODOBJS': 'Modules/posixmodule.o  Modules/errnomodule.o  '
@@ -609,7 +636,7 @@ build_time_vars = {'ABIFLAGS': '',
             'Modules/_localemodule.o  Modules/_iomodule.o Modules/iobase.o '
             'Modules/fileio.o Modules/bytesio.o Modules/bufferedio.o '
             'Modules/textio.o Modules/stringio.o  Modules/faulthandler.o  '
-            'Modules/_tracemalloc.o Modules/hashtable.o  '
+            'Modules/_tracemalloc.o  Modules/_peg_parser.o  '
             'Modules/symtablemodule.o  Modules/xxsubtype.o',
  'MODULE_OBJS': '\\',
  'MULTIARCH': 'x86_64-linux-gnu',
@@ -617,11 +644,11 @@ build_time_vars = {'ABIFLAGS': '',
  'MVWDELCH_IS_EXPRESSION': 1,
  'NO_AS_NEEDED': '-Wl,--no-as-needed',
  'OBJECT_OBJS': '\\',
- 'OPENSSL_INCLUDES': '-I/usr/pkg/include',
- 'OPENSSL_LDFLAGS': '-L/usr/pkg/lib',
+ 'OPENSSL_INCLUDES': '-I/2022Q1/include',
+ 'OPENSSL_LDFLAGS': '-L/2022Q1/lib',
  'OPENSSL_LIBS': '-lssl -lcrypto',
- 'OPT': '-DNDEBUG -O2 -D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include '
-        '-I/usr/pkg/include/ncurses -I/usr/pkg/include/db4',
+ 'OPT': '-DNDEBUG -O2 -D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q1/include '
+        '-I/2022Q1/include/ncurses -I/2022Q1/include/db4',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
@@ -630,9 +657,13 @@ build_time_vars = {'ABIFLAGS': '',
  'PACKAGE_URL': 0,
  'PACKAGE_VERSION': 0,
  'PARSER_HEADERS': '\\',
- 'PARSER_OBJS': '\\ Parser/myreadline.o Parser/parsetok.o Parser/tokenizer.o',
+ 'PARSER_OBJS': '\\ \\ Parser/myreadline.o Parser/parsetok.o '
+                'Parser/tokenizer.o',
+ 'PEGEN_HEADERS': '\\',
+ 'PEGEN_OBJS': '\\',
  'PGO_PROF_GEN_FLAG': '',
  'PGO_PROF_USE_FLAG': '',
+ 'PLATLIBDIR': 'lib',
  'POBJS': '\\',
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
  'PROFILE_TASK': '-m test --pgo',
@@ -648,86 +679,93 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHONFRAMEWORKPREFIX': '',
  'PYTHONPATH': '',
  'PYTHON_FOR_BUILD': './python -E',
- 'PYTHON_FOR_REGEN': 'python3',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
+ 'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha256,sha512,sha3,blake2"',
  'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 '
                              '-D_FORTIFY_SOURCE=2 -I/usr/include '
-                             '-I/usr/pkg/include -I/usr/pkg/include/ncurses '
-                             '-I/usr/pkg/include/db4 -O2 -D_FORTIFY_SOURCE=2 '
-                             '-I/usr/include -I/usr/pkg/include '
-                             '-I/usr/pkg/include/ncurses '
-                             '-I/usr/pkg/include/db4 -O2 -D_FORTIFY_SOURCE=2 '
-                             '-I/usr/include -I/usr/pkg/include '
-                             '-I/usr/pkg/include/ncurses '
-                             '-I/usr/pkg/include/db4 -std=gnu99 -Wextra '
+                             '-I/2022Q1/include -I/2022Q1/include/ncurses '
+                             '-I/2022Q1/include/db4 -O2 -D_FORTIFY_SOURCE=2 '
+                             '-I/usr/include -I/2022Q1/include '
+                             '-I/2022Q1/include/ncurses -I/2022Q1/include/db4 '
+                             '-O2 -D_FORTIFY_SOURCE=2 -I/usr/include '
+                             '-I/2022Q1/include -I/2022Q1/include/ncurses '
+                             '-I/2022Q1/include/db4 -std=gnu99 -Wextra '
                              '-Wno-unused-result -Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
-                             '-Werror=implicit-function-declaration  '
-                             '-I./Include/internal -I. -I./Include '
-                             '-I/usr/include -I/usr/pkg/include '
-                             '-I/usr/pkg/include/ncurses '
-                             '-I/usr/pkg/include/db4 -I/usr/include '
-                             '-I/usr/pkg/include -I/usr/pkg/include/ncurses '
-                             '-I/usr/pkg/include/db4 -fPIC '
-                             '-DPy_BUILD_CORE_BUILTIN',
+                             '-Werror=implicit-function-declaration '
+                             '-fvisibility=hidden  -I./Include/internal -I. '
+                             '-I./Include -I/usr/include -I/2022Q1/include '
+                             '-I/2022Q1/include/ncurses -I/2022Q1/include/db4 '
+                             '-I/usr/include -I/2022Q1/include '
+                             '-I/2022Q1/include/ncurses -I/2022Q1/include/db4 '
+                             '-fPIC -DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 '
-              '-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include '
-              '-I/usr/pkg/include/ncurses -I/usr/pkg/include/db4 -O2 '
-              '-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include '
-              '-I/usr/pkg/include/ncurses -I/usr/pkg/include/db4 -O2 '
-              '-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include '
-              '-I/usr/pkg/include/ncurses -I/usr/pkg/include/db4',
+              '-D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q1/include '
+              '-I/2022Q1/include/ncurses -I/2022Q1/include/db4 -O2 '
+              '-D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q1/include '
+              '-I/2022Q1/include/ncurses -I/2022Q1/include/db4 -O2 '
+              '-D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q1/include '
+              '-I/2022Q1/include/ncurses -I/2022Q1/include/db4',
  'PY_CFLAGS_NODIST': '-std=gnu99 -Wextra -Wno-unused-result '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
-                     '-Werror=implicit-function-declaration  '
-                     '-I./Include/internal',
+                     '-Werror=implicit-function-declaration '
+                     '-fvisibility=hidden  -I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 '
-                   '-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include '
-                   '-I/usr/pkg/include/ncurses -I/usr/pkg/include/db4 -O2 '
-                   '-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include '
-                   '-I/usr/pkg/include/ncurses -I/usr/pkg/include/db4 -O2 '
-                   '-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include '
-                   '-I/usr/pkg/include/ncurses -I/usr/pkg/include/db4 '
-                   '-std=gnu99 -Wextra -Wno-unused-result '
-                   '-Wno-unused-parameter -Wno-missing-field-initializers '
-                   '-Werror=implicit-function-declaration  '
+                   '-D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q1/include '
+                   '-I/2022Q1/include/ncurses -I/2022Q1/include/db4 -O2 '
+                   '-D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q1/include '
+                   '-I/2022Q1/include/ncurses -I/2022Q1/include/db4 -O2 '
+                   '-D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q1/include '
+                   '-I/2022Q1/include/ncurses -I/2022Q1/include/db4 -std=gnu99 '
+                   '-Wextra -Wno-unused-result -Wno-unused-parameter '
+                   '-Wno-missing-field-initializers '
+                   '-Werror=implicit-function-declaration -fvisibility=hidden  '
                    '-I./Include/internal -I. -I./Include -I/usr/include '
-                   '-I/usr/pkg/include -I/usr/pkg/include/ncurses '
-                   '-I/usr/pkg/include/db4 -I/usr/include -I/usr/pkg/include '
-                   '-I/usr/pkg/include/ncurses -I/usr/pkg/include/db4 -fPIC '
+                   '-I/2022Q1/include -I/2022Q1/include/ncurses '
+                   '-I/2022Q1/include/db4 -I/usr/include -I/2022Q1/include '
+                   '-I/2022Q1/include/ncurses -I/2022Q1/include/db4 -fPIC '
                    '-DPy_BUILD_CORE',
- 'PY_CORE_LDFLAGS': '-L. -Wl,-zrelro -L/usr/lib64 -Wl,-R/usr/lib64 '
-                    '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib -Wl,-zrelro '
-                    '-L/usr/lib64 -Wl,-R/usr/lib64 -L/usr/pkg/lib '
-                    '-Wl,-R/usr/pkg/lib',
- 'PY_CPPFLAGS': '-I. -I./Include -I/usr/include -I/usr/pkg/include '
-                '-I/usr/pkg/include/ncurses -I/usr/pkg/include/db4 '
-                '-I/usr/include -I/usr/pkg/include -I/usr/pkg/include/ncurses '
-                '-I/usr/pkg/include/db4',
+ 'PY_CORE_LDFLAGS': '-L. -L/2022Q1/gcc7/lib/gcc/x86_64-unknown-linux/7.5.0 '
+                    '-Wl,-R/2022Q1/gcc7/lib/gcc/x86_64-unknown-linux/7.5.0 '
+                    '-L/2022Q1/gcc7/lib64 -Wl,-R/2022Q1/gcc7/lib64 -Wl,-zrelro '
+                    '-L/2022Q1/lib -Wl,-R/2022Q1/lib '
+                    '-L/2022Q1/gcc7/lib/gcc/x86_64-unknown-linux/7.5.0 '
+                    '-Wl,-R/2022Q1/gcc7/lib/gcc/x86_64-unknown-linux/7.5.0 '
+                    '-L/2022Q1/gcc7/lib64 -Wl,-R/2022Q1/gcc7/lib64 -Wl,-zrelro '
+                    '-L/2022Q1/lib -Wl,-R/2022Q1/lib',
+ 'PY_CPPFLAGS': '-I. -I./Include -I/usr/include -I/2022Q1/include '
+                '-I/2022Q1/include/ncurses -I/2022Q1/include/db4 '
+                '-I/usr/include -I/2022Q1/include -I/2022Q1/include/ncurses '
+                '-I/2022Q1/include/db4',
  'PY_FORMAT_SIZE_T': '"z"',
- 'PY_LDFLAGS': '-L. -Wl,-zrelro -L/usr/lib64 -Wl,-R/usr/lib64 -L/usr/pkg/lib '
-               '-Wl,-R/usr/pkg/lib -Wl,-zrelro -L/usr/lib64 -Wl,-R/usr/lib64 '
-               '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib',
+ 'PY_LDFLAGS': '-L. -L/2022Q1/gcc7/lib/gcc/x86_64-unknown-linux/7.5.0 '
+               '-Wl,-R/2022Q1/gcc7/lib/gcc/x86_64-unknown-linux/7.5.0 '
+               '-L/2022Q1/gcc7/lib64 -Wl,-R/2022Q1/gcc7/lib64 -Wl,-zrelro '
+               '-L/2022Q1/lib -Wl,-R/2022Q1/lib '
+               '-L/2022Q1/gcc7/lib/gcc/x86_64-unknown-linux/7.5.0 '
+               '-Wl,-R/2022Q1/gcc7/lib/gcc/x86_64-unknown-linux/7.5.0 '
+               '-L/2022Q1/gcc7/lib64 -Wl,-R/2022Q1/gcc7/lib64 -Wl,-zrelro '
+               '-L/2022Q1/lib -Wl,-R/2022Q1/lib',
  'PY_LDFLAGS_NODIST': '',
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 '
-                        '-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include '
-                        '-I/usr/pkg/include/ncurses -I/usr/pkg/include/db4 -O2 '
-                        '-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include '
-                        '-I/usr/pkg/include/ncurses -I/usr/pkg/include/db4 -O2 '
-                        '-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include '
-                        '-I/usr/pkg/include/ncurses -I/usr/pkg/include/db4 '
+                        '-D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q1/include '
+                        '-I/2022Q1/include/ncurses -I/2022Q1/include/db4 -O2 '
+                        '-D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q1/include '
+                        '-I/2022Q1/include/ncurses -I/2022Q1/include/db4 -O2 '
+                        '-D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q1/include '
+                        '-I/2022Q1/include/ncurses -I/2022Q1/include/db4 '
                         '-std=gnu99 -Wextra -Wno-unused-result '
                         '-Wno-unused-parameter -Wno-missing-field-initializers '
-                        '-Werror=implicit-function-declaration  '
-                        '-I./Include/internal -I. -I./Include -I/usr/include '
-                        '-I/usr/pkg/include -I/usr/pkg/include/ncurses '
-                        '-I/usr/pkg/include/db4 -I/usr/include '
-                        '-I/usr/pkg/include -I/usr/pkg/include/ncurses '
-                        '-I/usr/pkg/include/db4 -fPIC',
+                        '-Werror=implicit-function-declaration '
+                        '-fvisibility=hidden  -I./Include/internal -I. '
+                        '-I./Include -I/usr/include -I/2022Q1/include '
+                        '-I/2022Q1/include/ncurses -I/2022Q1/include/db4 '
+                        '-I/usr/include -I/2022Q1/include '
+                        '-I/2022Q1/include/ncurses -I/2022Q1/include/db4 -fPIC',
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
  'Py_HASH_ALGORITHM': 0,
@@ -736,14 +774,13 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/usr/pkgsrc/lang/python38/work/Python-3.8.14',
- 'SCRIPTDIR': '/usr/pkg/lib',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/root/sda3/pkgsrc.2022Q1/lang/python39/work/Python-3.9.12',
+ 'SCRIPTDIR': '/2022Q1/lib',
  'SETPGRP_HAVE_ARG': 0,
- 'SGI_ABI': '@SGI_ABI@',
  'SHELL': '/bin/sh',
- 'SHLIBS': '-lcrypt -lintl -ldl  -lm',
+ 'SHLIBS': '-lcrypt -lintl -lpthread -ldl  -lutil -lm',
  'SHLIB_SUFFIX': '.so',
- 'SHM_NEEDS_LIBRT': 0,
+ 'SHM_NEEDS_LIBRT': 1,
  'SIGNED_RIGHT_SHIFT_ZERO_FILLS': 0,
  'SITEPATH': '',
  'SIZEOF_DOUBLE': 8,
@@ -764,8 +801,8 @@ build_time_vars = {'ABIFLAGS': '',
  'SIZEOF_VOID_P': 8,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
- 'SOABI': 'cpython-38-x86_64-linux-gnu',
- 'SRCDIRS': 'Parser Objects Python Modules Modules/_io Programs',
+ 'SOABI': 'cpython-39-x86_64-linux-gnu',
+ 'SRCDIRS': 'Parser Parser/pegen Objects Python Modules Modules/_io Programs',
  'SRC_GDB_HOOKS': './Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
@@ -778,20 +815,21 @@ build_time_vars = {'ABIFLAGS': '',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/usr/pkgsrc/lang/python38/work/Python-3.8.14 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/root/sda3/pkgsrc.2022Q1/lang/python39/work/Python-3.9.12 '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/usr/pkgsrc/lang/python38/work/Python-3.8.14 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/root/sda3/pkgsrc.2022Q1/lang/python39/work/Python-3.9.12 '
                './python ./Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'TIMEMODULE_LIB': 0,
  'TIME_WITH_SYS_TIME': 1,
  'TM_IN_SYS_TIME': 0,
+ 'TZPATH': '/usr/share/zoneinfo:/usr/lib/zoneinfo:/usr/share/lib/zoneinfo:/etc/zoneinfo',
  'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
- 'UPDATE_FILE': 'python3 ./Tools/scripts/update_file.py',
+ 'UPDATE_FILE': 'python3.9 ./Tools/scripts/update_file.py',
  'USE_COMPUTED_GOTOS': 0,
- 'VERSION': '3.8',
+ 'VERSION': '3.9',
  'WINDOW_HAS_FLAGS': 1,
  'WITH_DECIMAL_CONTEXTVAR': 1,
  'WITH_DOC_STRINGS': 1,
@@ -803,9 +841,9 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/usr/pkgsrc/lang/python38/work/Python-3.8.14',
- 'abs_srcdir': '/usr/pkgsrc/lang/python38/work/Python-3.8.14',
- 'datarootdir': '/usr/pkg/share',
- 'exec_prefix': '/usr/pkg',
- 'prefix': '/usr/pkg',
+ 'abs_builddir': '/root/sda3/pkgsrc.2022Q1/lang/python39/work/Python-3.9.12',
+ 'abs_srcdir': '/root/sda3/pkgsrc.2022Q1/lang/python39/work/Python-3.9.12',
+ 'datarootdir': '/2022Q1/share',
+ 'exec_prefix': '/2022Q1',
+ 'prefix': '/2022Q1',
  'srcdir': '.'}
