@@ -117,7 +117,7 @@ elif os.name == "posix":
 
         temp = tempfile.NamedTemporaryFile()
         try:
-            args = [c_compiler, '-Wl,-R/usr/pkg/lib', '-L/usr/pkg/lib', '-Wl,-R/usr/pkg/lib', '-L/usr/pkg/lib', '-Wl,-t', '-o', temp.name, '-l' + name]
+            args = [c_compiler, '-Wl,-R/2022Q1/lib', '-L/2022Q1/lib', '-Wl,-R/2022Q1/lib', '-L/2022Q1/lib', '-Wl,-t', '-o', temp.name, '-l' + name]
 
             env = dict(os.environ)
             env['LC_ALL'] = 'C'
@@ -234,9 +234,9 @@ elif os.name == "posix":
             env['LC_ALL'] = 'C'
 
             if is64:
-                paths = "/lib/64:/usr/lib/64:/usr/pkg/lib"
+                paths = "/lib/64:/usr/lib/64:/2022Q1/lib"
             else:
-                paths = "/lib:/usr/lib:/usr/pkg/lib"
+                paths = "/lib:/usr/lib:/2022Q1/lib"
 
             for dir in paths.split(":"):
                 libfile = os.path.join(dir, "lib%s.so" % name)
@@ -283,7 +283,7 @@ elif os.name == "posix":
         def _findLib_ld(name):
             # See issue #9998 for why this is needed
             expr = r'[^\(\)\s]*lib%s\.[^\(\)\s]*' % re.escape(name)
-            cmd = ['ld', '-t', '-L', '/usr/pkg/lib']
+            cmd = ['ld', '-t', '-L', '/2022Q1/lib']
             libpath = os.environ.get('LD_LIBRARY_PATH')
             if libpath:
                 for d in libpath.split(':'):
