@@ -1,4 +1,4 @@
-#!/usr/pkg/bin/python3.8
+#!/2022Q1/bin/python3.9
 
 import sys
 if __name__ == "__main__":
@@ -60,6 +60,13 @@ from idlelib.undo import UndoDelegator
 HOST = '127.0.0.1' # python execution server on localhost loopback
 PORT = 0  # someday pass in host, port for remote debug capability
 
+try:  # In case IDLE started with -n.
+    eof = 'Ctrl-D (end-of-file)'
+    exit.eof = eof
+    quit.eof = eof
+except NameError: # In case python started with -S.
+    pass
+
 # Override warnings module to write to warning_stream.  Initialize to send IDLE
 # internal warnings to the console.  ScriptBinding.check_syntax() will
 # temporarily redirect the stream to the shell window to display warnings when
